import { defineConfig, copy, isFunction } from '@agile-ts/utils';
import { LogCodeManager } from '../logCodeManager.js';
import { StateObserver } from './state.observer.js';
import { ComputedTracker } from '../computed/computed.tracker.js';

class State {
  constructor(agileInstance, initialValue, config = {}) {
    this.isSet = false;
    this.isPlaceholder = false;
    this.observers = {};
    this.sideEffects = {};
    config = defineConfig(config, {
      dependents: [],
      isPlaceholder: false
    });
    this.agileInstance = () => agileInstance;
    this._key = config.key;
    this.observers["value"] = new StateObserver(this, {
      key: config.key,
      dependents: config.dependents
    });
    this.initialStateValue = copy(initialValue);
    this._value = copy(initialValue);
    this.previousStateValue = copy(initialValue);
    this.nextStateValue = copy(initialValue);
    this.isPlaceholder = true;
    if (!config.isPlaceholder)
      this.set(initialValue, { overwrite: true });
  }
  set value(value) {
    this.set(value);
  }
  get value() {
    ComputedTracker.tracked(this.observers["value"]);
    return copy(this._value);
  }
  set key(value) {
    this.setKey(value);
  }
  get key() {
    return this._key;
  }
  setKey(value) {
    this._key = value;
    for (const observerKey in this.observers)
      this.observers[observerKey]._key = value;
    return this;
  }
  set(value, config = {}) {
    config = defineConfig(config, {
      force: false
    });
    const _value = isFunction(value) ? value(copy(this._value)) : value;
    this.observers["value"].ingestValue(_value, config);
    return this;
  }
  ingest(config = {}) {
    this.observers["value"].ingest(config);
    return this;
  }
  addSideEffect(key, callback, config = {}) {
    config = defineConfig(config, {
      weight: 10
    });
    if (!isFunction(callback)) {
      LogCodeManager.log("00:03:01", ["Side Effect Callback", "function"]);
      return this;
    }
    this.sideEffects[key] = {
      callback,
      weight: config.weight
    };
    return this;
  }
  removeSideEffect(key) {
    delete this.sideEffects[key];
    return this;
  }
  hasSideEffect(key) {
    return !!this.sideEffects[key];
  }
}

export { State };
