declare const logCodeTypes: {
    '00': string;
    '01': string;
    '02': string;
    '03': string;
};
declare const niceLogCodeMessages: {
    '10:00:00': string;
    '10:02:00': string;
    '11:02:00': string;
    '11:02:01': string;
    '11:03:00': string;
    '11:03:01': string;
    '11:03:02': string;
    '11:03:03': string;
    '11:03:04': string;
    '11:03:05': string;
    '12:03:00': string;
    '12:03:01': string;
    '12:03:02': string;
    '13:00:00': string;
    '13:01:00': string;
    '13:01:01': string;
    '13:01:02': string;
    '13:02:00': string;
    '13:03:00': string;
    '14:03:01': string;
    '14:03:02': string;
    '14:03:03': string;
    '14:03:04': string;
    '15:01:00': string;
    '15:01:01': string;
    '15:01:02': string;
    '15:01:03': string;
    '16:01:00': string;
    '16:01:01': string;
    '16:01:02': string;
    '16:02:00': string;
    '16:02:01': string;
    '17:03:00': string;
    '18:00:00': string;
    '18:02:00': string;
    '18:03:00': string;
    '1A:02:00': string;
    '1A:02:01': string;
    '1B:02:00': string;
    '1B:02:01': string;
    '1B:02:02': string;
    '1B:02:03': string;
    '1B:02:04': string;
    '1B:02:05': string;
    '1B:03:00': string;
    '1B:03:01': string;
    '1B:03:02': string;
    '1B:03:03': string;
    '1B:03:04': string;
    '1B:03:05': string;
    '1B:03:06': string;
    '1C:02:00': string;
    '1C:03:00': string;
    '1C:03:01': string;
    '20:03:00': string;
    '20:03:01': string;
    '20:03:02': string;
    '00:03:00': string;
    '00:03:01': string;
};
declare const logCodeMessages: typeof niceLogCodeMessages;
/**
 * Creates an extension of the specified LogCodeManager
 * and assigns the provided additional log messages to it.
 *
 * @param additionalLogs - Log messages to be added to the LogCodeManager.
 * @param logCodeManager - LogCodeManager to create an extension from.
 */
export declare function assignAdditionalLogs<NewLogCodeMessages, OldLogCodeMessages = typeof logCodeMessages>(additionalLogs: {
    [key: string]: string;
}, logCodeManager: LogCodeManagerInterface<OldLogCodeMessages>): LogCodeManagerInterface<NewLogCodeMessages>;
/**
 * The Log Code Manager keeps track
 * and manages all important Logs for the '@agile-ts/core' package.
 *
 * @internal
 */
export declare const LogCodeManager: LogCodeManagerInterface<{
    '10:00:00': string;
    '10:02:00': string;
    '11:02:00': string;
    '11:02:01': string;
    '11:03:00': string;
    '11:03:01': string;
    '11:03:02': string;
    '11:03:03': string;
    '11:03:04': string;
    '11:03:05': string;
    '12:03:00': string;
    '12:03:01': string;
    '12:03:02': string;
    '13:00:00': string;
    '13:01:00': string;
    '13:01:01': string;
    '13:01:02': string;
    '13:02:00': string;
    '13:03:00': string;
    '14:03:01': string;
    '14:03:02': string;
    '14:03:03': string;
    '14:03:04': string;
    '15:01:00': string;
    '15:01:01': string;
    '15:01:02': string;
    '15:01:03': string;
    '16:01:00': string;
    '16:01:01': string;
    '16:01:02': string;
    '16:02:00': string;
    '16:02:01': string;
    '17:03:00': string;
    '18:00:00': string;
    '18:02:00': string;
    '18:03:00': string;
    '1A:02:00': string;
    '1A:02:01': string;
    '1B:02:00': string;
    '1B:02:01': string;
    '1B:02:02': string;
    '1B:02:03': string;
    '1B:02:04': string;
    '1B:02:05': string;
    '1B:03:00': string;
    '1B:03:01': string;
    '1B:03:02': string;
    '1B:03:03': string;
    '1B:03:04': string;
    '1B:03:05': string;
    '1B:03:06': string;
    '1C:02:00': string;
    '1C:03:00': string;
    '1C:03:01': string;
    '20:03:00': string;
    '20:03:01': string;
    '20:03:02': string;
    '00:03:00': string;
    '00:03:01': string;
}>;
export declare type LogCodesArrayType<T> = {
    [K in keyof T]: T[K] extends string ? K : never;
}[keyof T] & string;
export interface LogCodeManagerInterface<T = typeof logCodeMessages> {
    getLog: (logCode: LogCodesArrayType<T>, replacers?: any[]) => string;
    log: (logCode: LogCodesArrayType<T>, replacers?: any[], ...data: any[]) => void;
    logCodeLogTypes: typeof logCodeTypes;
    logCodeMessages: T;
    getLogger: () => any;
    logIfTags: (tags: string[], logCode: LogCodesArrayType<T>, replacers?: any[], ...data: any[]) => void;
    setAllowLogging: (logging: boolean) => void;
}
export {};
